# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

from trytond.pool import Pool

from . import party
from . import company
from . import res

__all__ = ['register']


def register():
    Pool.register(
        party.Party,
        module='party_avatar', type_='model')
    Pool.register(
        company.Company,
        company.Employee,
        res.User,
        module='party_avatar', type_='model', depends=['company'])



# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

from trytond.pool import PoolMeta


class User(metaclass=PoolMeta):
    __name__ = 'res.user'

    def get_avatar_badge_url(self, name):
        url = super().get_avatar_badge_url(name)
        if self.company:
            url = self.company.avatar_url
        return url



# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

from trytond.model import avatar_mixin
from trytond.pool import PoolMeta


class Party(avatar_mixin(200, 'name'), metaclass=PoolMeta):
    __name__ = 'party.party'



# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

from trytond.i18n import lazy_gettext
from trytond.model import fields
from trytond.pool import PoolMeta


class Company(metaclass=PoolMeta):
    __name__ = 'company.company'

    avatar_url = fields.Function(
        fields.Char(lazy_gettext('ir.msg_avatar_url')), 'get_avatar_url')

    def get_avatar_url(self, name):
        return self.party.avatar_url


class Employee(metaclass=PoolMeta):
    __name__ = 'company.employee'

    avatar_url = fields.Function(
        fields.Char(lazy_gettext('ir.msg_avatar_url')), 'get_avatar_url')

    def get_avatar_url(self, name):
        return self.party.avatar_url



# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

import unittest

from trytond.tests.test_tryton import ModuleTestCase
from trytond.tests.test_tryton import suite as test_suite

from trytond.modules.company.tests import CompanyTestMixin


class PartyAvatarTestCase(CompanyTestMixin, ModuleTestCase):
    'Test Party Avatar module'
    module = 'party_avatar'
    extras = ['company']


def suite():
    suite = test_suite()
    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
            PartyAvatarTestCase))
    return suite
